# Atypical Tracker (atpcl)
Atypical One Time Tracker

Package structure

```
.
├── LICENSE
├── README.md
├── setup.py
├── src
│   └── atpcl_tracker
│       ├── __init__.py
│       ├── atpcl-tracker.py
│       └── services
│           ├── api
│           ├── core
│           └── utils
└── venv
```

## Installation
```
pip install atpcl
```

## Usage
 
Work In Progress